==> ml-pnet-0.6.8.tar.gz: ml-pnet-0.6.8/mcs-sources/class/System.Security/System.Security.Cryptography.Pkcs/KeyAgreeRecipientInfo.cs <==
//
// KeyAgreeRecipientInfo.cs - System.Security.Cryptography.Pkcs.KeyAgreeRecipientInfo
//
// Author:
//	Sebastien Pouliot  <sebastien@ximian.com>
//
// (C) 2003 Motus Technologies Inc. (http://www.motus.com)
// Copyright (C) 2004 Novell Inc. (http://www.novell.com)
//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;

namespace System.Security.Cryptography.Pkcs {

	[MonoTODO]
	public sealed class KeyAgreeRecipientInfo : RecipientInfo {

		// only accessible from EnvelopedCms.RecipientInfos
		internal KeyAgreeRecipientInfo () 
			: base (RecipientInfoType.KeyAgreement) 
		{
		}

		public DateTime Date {
			get { return DateTime.MinValue; }
		}

		public override byte[] EncryptedKey {
			get { return null; }
		}

		public override AlgorithmIdentifier KeyEncryptionAlgorithm {
			get { return null; }
		}

		public SubjectIdentifierOrKey OriginatorIdentifierOrKey {
			get { return null; }
		}

		public CryptographicAttribute OtherKeyAttribute {
			get { return null; }
		}

		public override SubjectIdentifier RecipientIdentifier {
			get { return null; }
		}

		public override int Version {
			get { return 0; }
		}
	}
}

#endif

==> ml-pnet-0.6.10.tar.gz: ml-pnet-0.6.10/mcs-sources/class/System.Security/System.Security.Cryptography.Pkcs/KeyAgreeRecipientInfo.cs <==
//
// KeyAgreeRecipientInfo.cs - System.Security.Cryptography.Pkcs.KeyAgreeRecipientInfo
//
// Author:
//	Sebastien Pouliot (spouliot@motus.com)
//
// (C) 2003 Motus Technologies Inc. (http://www.motus.com)
//

//
// Permission is hereby granted, free of charge, to any person obtaining
// a copy of this software and associated documentation files (the
// "Software"), to deal in the Software without restriction, including
// without limitation the rights to use, copy, modify, merge, publish,
// distribute, sublicense, and/or sell copies of the Software, and to
// permit persons to whom the Software is furnished to do so, subject to
// the following conditions:
// 
// The above copyright notice and this permission notice shall be
// included in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
// EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
// MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
// NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
// LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
// OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
// WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
//

#if NET_2_0

using System;

namespace System.Security.Cryptography.Pkcs {

	[MonoTODO]
	public sealed class KeyAgreeRecipientInfo : RecipientInfo {

		// only accessible from EnvelopedPkcs7.RecipientInfos
		internal KeyAgreeRecipientInfo () {}

		public DateTime Date {
			get { return DateTime.MinValue; }
		}

		public override byte[] EncryptedKey {
			get { return null; }
		}

		public override AlgorithmIdentifier KeyEncryptionAlgorithm {
			get { return null; }
		}

		public SubjectIdentifierOrKey OriginatorIdentifierOrKey {
			get { return null; }
		}

		public CryptographicAttribute OtherKeyAttribute {
			get { return null; }
		}

		public override SubjectIdentifier RecipientIdentifier {
			get { return null; }
		}

		public override int Version {
			get { return 0; }
		}
	}
}

#endif
